@@ -114,8 +114,9 @@ def install_conda_pkgs(anaconda):
     pkgs = ["cython", "ipython", "jinja2", "nose", "numpy",
             "pip", "pycrypto", "pyparsing", "pysam", "pyyaml",
             "pyzmq", "pandas", "scipy"]
+    channels = ["-c", "https://conda.binstar.org/collections/chapmanb/bcbio"]
     subprocess.check_call([anaconda["conda"], "install", "--yes", "numpy"])
-    subprocess.check_call([anaconda["conda"], "install", "--yes"] + pkgs)
+    subprocess.check_call([anaconda["conda"], "install", "--yes"] + channels + pkgs)
 
 def install_anaconda_python(args, remotes):
     """Provide isolated installation of Anaconda python.
